@@ -123,7 +123,7 @@ void merge2_RM(arma::uvec& y, int left, int middle, int right, arma::uvec& count
             int jIndex  = sampleInds(IAcounter(firstInd + dupNumber),
                                      firstInd + dupNumber) - counts(Left(i)); // has to be within 0, j
             double intersection;
-            if (arma::is_finite(theta_lo) && arma::is_finite(theta_hi))
+            if (std::isfinite(theta_lo) && std::isfinite(theta_hi))
             {
               if (X(valToline(Right(jIndex))) == X(valToline(Left(i)))) 
               {
@@ -185,7 +185,7 @@ void merge2_RM(arma::uvec& y, int left, int middle, int right, arma::uvec& count
                                         firstInd + dupNumber) - counts(Right(j));
             
             double intersection;
-            if (arma::is_finite(theta_lo) && arma::is_finite(theta_hi))
+            if (std::isfinite(theta_lo) && std::isfinite(theta_hi))
             {
               // use more robust formula to compute the sampled intersection ordinate:
               double delta_lo = (theta_lo * X(valToline(Right(j))) -
@@ -230,7 +230,7 @@ void merge2_RM(arma::uvec& y, int left, int middle, int right, arma::uvec& count
                                    firstInd + dupNumber) - counts(Left(i)); // has to be within 0, j
           // use more robust formula to compute the sampled intersection ordinate:
           double intersection;
-          if (arma::is_finite(theta_lo) && arma::is_finite(theta_hi))
+          if (std::isfinite(theta_lo) && std::isfinite(theta_hi))
           {
             double delta_lo = (theta_lo * X(valToline(Right(jIndex))) -
                                Y(valToline(Right(jIndex)))) -
